Learn R Programming

ZINAR1 (version 0.1.0)

PghTracts: Drug Offenses

Description

Monthly number of drug offenses recorded from January 1990 to December 2001, with 144 observations, in Pittsburgh census tract 2206.

Usage

PghTracts

Arguments

Format

A data frame with 144 rows and 4 columns containing the census tract and the variables YEAR,MONTH and DRUGS.